@@ -30,7 +30,7 @@ qx.Class.define("callbackery.ui.Popup", {
         });
         var extraAction = {
             label : 'Cancel',
-            action : 'cancel',
+            action : 'cancel'
         };
         if (cfg.cancelLabel) {
             extraAction.label = cfg.cancelLabel;
